==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/equipmentcategory_001/EquipmentCategory.java <==

package net.datastream.schemas.mp_entities.equipmentcategory_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITREVIEWEDBY" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "categoryid",
    "classid",
    "manufacturerid",
    "userdefinedarea",
    "safetydatereviewrequired",
    "safetyreviewedby",
    "permitdatereviewrequired",
    "permitreviewedby"
})
@XmlRootElement(name = "EquipmentCategory")
public class EquipmentCategory {

    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CATEGORYID categoryid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "SAFETYDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME safetydatereviewrequired;
    @XmlElement(name = "SAFETYREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type safetyreviewedby;
    @XmlElement(name = "PERMITDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permitdatereviewrequired;
    @XmlElement(name = "PERMITREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type permitreviewedby;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Obtient la valeur de la propriété categoryid.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Définit la valeur de la propriété categoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerid.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Définit la valeur de la propriété manufacturerid.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedarea.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Définit la valeur de la propriété userdefinedarea.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Obtient la valeur de la propriété safetydatereviewrequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSAFETYDATEREVIEWREQUIRED() {
        return safetydatereviewrequired;
    }

    /**
     * Définit la valeur de la propriété safetydatereviewrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSAFETYDATEREVIEWREQUIRED(DATETIME value) {
        this.safetydatereviewrequired = value;
    }

    /**
     * Obtient la valeur de la propriété safetyreviewedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getSAFETYREVIEWEDBY() {
        return safetyreviewedby;
    }

    /**
     * Définit la valeur de la propriété safetyreviewedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setSAFETYREVIEWEDBY(USERID_Type value) {
        this.safetyreviewedby = value;
    }

    /**
     * Obtient la valeur de la propriété permitdatereviewrequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMITDATEREVIEWREQUIRED() {
        return permitdatereviewrequired;
    }

    /**
     * Définit la valeur de la propriété permitdatereviewrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMITDATEREVIEWREQUIRED(DATETIME value) {
        this.permitdatereviewrequired = value;
    }

    /**
     * Obtient la valeur de la propriété permitreviewedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getPERMITREVIEWEDBY() {
        return permitreviewedby;
    }

    /**
     * Définit la valeur de la propriété permitreviewedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setPERMITREVIEWEDBY(USERID_Type value) {
        this.permitreviewedby = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété user_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Définit la valeur de la propriété user_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Obtient la valeur de la propriété system_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Définit la valeur de la propriété system_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/equipmentcategory_001/EquipmentCategory.java <==

package net.datastream.schemas.mp_entities.equipmentcategory_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETYREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITDATEREVIEWREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERMITREVIEWEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEMATICID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "categoryid",
    "classid",
    "manufacturerid",
    "userdefinedarea",
    "safetydatereviewrequired",
    "safetyreviewedby",
    "permitdatereviewrequired",
    "permitreviewedby",
    "schematicid"
})
@XmlRootElement(name = "EquipmentCategory")
public class EquipmentCategory {

    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CATEGORYID categoryid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "SAFETYDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME safetydatereviewrequired;
    @XmlElement(name = "SAFETYREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type safetyreviewedby;
    @XmlElement(name = "PERMITDATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME permitdatereviewrequired;
    @XmlElement(name = "PERMITREVIEWEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type permitreviewedby;
    @XmlElement(name = "SCHEMATICID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type schematicid;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Obtient la valeur de la propriété categoryid.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Définit la valeur de la propriété categoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerid.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Définit la valeur de la propriété manufacturerid.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedarea.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Définit la valeur de la propriété userdefinedarea.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Obtient la valeur de la propriété safetydatereviewrequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSAFETYDATEREVIEWREQUIRED() {
        return safetydatereviewrequired;
    }

    /**
     * Définit la valeur de la propriété safetydatereviewrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSAFETYDATEREVIEWREQUIRED(DATETIME value) {
        this.safetydatereviewrequired = value;
    }

    /**
     * Obtient la valeur de la propriété safetyreviewedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getSAFETYREVIEWEDBY() {
        return safetyreviewedby;
    }

    /**
     * Définit la valeur de la propriété safetyreviewedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setSAFETYREVIEWEDBY(USERID_Type value) {
        this.safetyreviewedby = value;
    }

    /**
     * Obtient la valeur de la propriété permitdatereviewrequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPERMITDATEREVIEWREQUIRED() {
        return permitdatereviewrequired;
    }

    /**
     * Définit la valeur de la propriété permitdatereviewrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPERMITDATEREVIEWREQUIRED(DATETIME value) {
        this.permitdatereviewrequired = value;
    }

    /**
     * Obtient la valeur de la propriété permitreviewedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getPERMITREVIEWEDBY() {
        return permitreviewedby;
    }

    /**
     * Définit la valeur de la propriété permitreviewedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setPERMITREVIEWEDBY(USERID_Type value) {
        this.permitreviewedby = value;
    }

    /**
     * Obtient la valeur de la propriété schematicid.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getSCHEMATICID() {
        return schematicid;
    }

    /**
     * Définit la valeur de la propriété schematicid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setSCHEMATICID(USERDEFINEDCODEID_Type value) {
        this.schematicid = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété user_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Définit la valeur de la propriété user_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Obtient la valeur de la propriété system_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Définit la valeur de la propriété system_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}
